TimeReporter

Struct TimeReporter 

pub struct TimeReporter { /* private fields */ }
Collect and report total time spent on set of activities.

TimeReporter is useful for generating and reporting time reports: how much time was spend on a given activity.

On drop or on call to finish it will report total times gathered as a tracing event.

Implementations

Source

impl TimeReporter

pub fn new<S: Into<String>>(name: S) -> Self

Create a new TimeReporter.

pub fn new_with_level<S: Into<String>>(name: S, level: Level) -> Self

Create a new TimeReporter with a specified level.

pub fn start(&mut self, key: &'static str)

Start counting time for a state named “key”.

If this TimeReporter was already counting time for another state, it will end counting time for it before starting a new one.

pub fn start_with<F, R>(&mut self, key: &'static str, f: F) -> R
where F: FnOnce() -> R,

Start counting time and execute a function f.

This is handy syntax for if let or while let expressions where it would be inconvenient to add a standalone start call.

pub fn stop(&mut self)

Stop counting time.

pub fn finish(self)

Finish counting time and report results.